<?php
/**
 * Set up config object, store plugin URL and path there
 * along with various other items
 */

\Data443\LGPD\Container::getInstance()->bindIf(
	'config',
	function () {
		return new \Data443\LGPD\Config(
			array(
				'plugin' => array(
					'url'           => plugin_dir_url( __FILE__ ),
					'path'          => plugin_dir_path( __FILE__ ),
					'template_path' => plugin_dir_path( __FILE__ ) . 'views/',
				),
				'help'   => array(
					'url' => 'https://www.data443.com/lgpd-framework/',
				),
			)
		);
	},
	true
);

/**
 * Set up the application container
 *
 * @param string                 $abstract
 * @param array                  $parameters
 * @param Data443\LGPD\Container $container
 *
 * @return Data443\LGPD\Container|mixed
 */
function lgpd( $abstract = null, $parameters = array(), Data443\LGPD\Container $container = null ) {
	$container = $container ?: Data443\LGPD\Container::getInstance();

	if ( ! $abstract ) {
		return $container;
	}

	return $container->bound( $abstract )
		? $container->makeWith( $abstract, $parameters )
		: $container->makeWith( "lgpd.{$abstract}", $parameters );
}

/**
 * Start the plugin on plugins_loaded at priority 0.
 */
add_action(
	'plugins_loaded',
	function () use ( $lgpd_error ) {

		load_plugin_textdomain( 'lgpd-framework', false, basename( dirname( __FILE__ ) ) . '/languages/' );

		$locale = is_admin() && function_exists( 'get_user_locale' ) ? get_user_locale() : get_locale();

		$locale = apply_filters( 'plugin_locale', $locale, 'lgpd-framework' );

		unload_textdomain( 'lgpd-framework' );

		load_textdomain( 'lgpd-framework', get_stylesheet_directory() . '/lgpd-framework/languages/' . 'lgpd-framework' . '-' . $locale . '.mo' );

		new \Data443\LGPD\Updater\Updater();

		new \Data443\LGPD\Setup();

	},
	0
);
