<?php

namespace Data443\LGPD\DataSubject;

use Data443\LGPD\Components\Consent\ConsentManager;

/**
 * Handles finding data subjects by ID or email
 *
 * Class DataSubjectManager
 *
 * @package Data443\LGPD\DataSubject
 */
class DataSubjectManager {

	/* @var ConsentManager */
	protected $consentManager;

	/**
	 * DataSubjectManager constructor.
	 *
	 * @param ConsentManager $consentManager
	 */
	public function __construct( ConsentManager $consentManager ) {
		$this->consentManager = $consentManager;
	}

	/**
	 * @param $email
	 * @return DataSubject
	 */
	public function getByEmail( $email ) {
		$email = sanitize_email( $email );
		$user  = get_user_by( 'email', $email );

		return lgpd()->makeWith(
			DataSubject::class,
			array(
				'email'          => $email,
				'user'           => $user ? $user : null,
				'consentManager' => $this->consentManager,
			)
		);
	}

	 /**
	  * @param $email
	  * @return DataSubject
	  */
	public function getuserlogs( $email ) {
		$user = get_user_by( 'email', sanitize_email( $email ) );

	}

	/**
	 * @param $id
	 * @return DataSubject|false
	 */
	public function getById( $id ) {
		$user = get_user_by( 'id', intval( $id ) );

		if ( ! $user ) {
			return false;
		}

		return lgpd()->makeWith(
			DataSubject::class,
			array(
				'email'          => sanitize_email( $user->user_email ),
				'user'           => $user,
				'consentManager' => $this->consentManager,
			)
		);
	}

	/**
	 * @return bool|DataSubject
	 */
	public function getByLoggedInUser() {
		if ( ! is_user_logged_in() ) {
			return false;
		}

		return $this->getById( get_current_user_id() );
	}
}
