<?php

namespace Data443\LGPD;

use Data443\LGPD\Admin\AdminTab;
use Data443\LGPD\Components\Consent\ConsentManager;
use Data443\LGPD\Components\PrivacyToolsPage\PrivacyToolsPage;
use Data443\LGPD\Components\PrivacyPolicy\PrivacyPolicy;
use Data443\LGPD\Components\AdvancedIntegration\AdvancedIntegration;
use Data443\LGPD\Components\PrivacyManager\PrivacyManager;
use Data443\LGPD\Components\PrivacySafe\PrivacySafe;
use Data443\LGPD\Components\DoNotSell\DoNotSell;
use Data443\LGPD\Components\CookiePopup\CookiePopup;
use Data443\LGPD\Components\Support\Support;
use Data443\LGPD\Components\WordpressComments\WordpressComments;
use Data443\LGPD\DataSubject\DataExporter;
use Data443\LGPD\DataSubject\DataSubjectAdmin;
use Data443\LGPD\DataSubject\DataSubjectIdentificator;
use Data443\LGPD\DataSubject\DataSubjectManager;
use Data443\LGPD\Modules\ContactForm7\ContactForm7;
use Data443\LGPD\Modules\WooCommerceCcpa\WooCommerceCcpa;
use Data443\LGPD\Modules\NewsletterCcpa\NewsletterCcpa;
use Data443\LGPD\Modules\EddCcpa\EddCcpa;
use Data443\LGPD\Components\Themes\Themes;
use Data443\LGPD\Components\WordpressUser\WordpressUser;
use Data443\LGPD\Modules\ContactForm7\Flamingo;
use Data443\LGPD\Modules\WPML\WPML;
use Data443\LGPD\Options\Options;

/**
 * Instantiate components
 *
 * Class Setup
 * @package Data443\LGPD
 */
class Setup
{
    /**
     * Setup constructor.
     */
    public function __construct()
    {
        $this->registerComponents();
        $this->runComponents();

        add_action('init', function() {

            if (!is_admin()) {
                return;
            }

            lgpd()->singleton(SetupAdmin::class);
            lgpd(SetupAdmin::class);
        }, 0);
    }

    /**
     * Register required components in the container
     */
    protected function registerComponents()
    {
        lgpd()->bind(Router::class);
        lgpd()->bind(DataExporter::class);

        lgpd()->singleton(PrivacyToolsPage::class);

        lgpd()->singleton(AdminTab::class);
        lgpd()->singleton(DataSubjectManager::class);
        lgpd()->singleton(DataSubjectIdentificator::class);
        lgpd()->singleton(View::class);
        lgpd()->singleton(Options::class);
        lgpd()->singleton(ConsentManager::class);
        lgpd()->singleton(Helpers::class);
        lgpd()->singleton(Themes::class);

        lgpd()->alias(View::class, 'view');
        lgpd()->alias(Options::class, 'options');
        lgpd()->alias(ConsentManager::class, 'consent');
        lgpd()->alias(Helpers::class, 'helpers');
        lgpd()->alias(Themes::class, 'themes');
        lgpd()->alias(DataSubjectManager::class, 'data-subject');
    }

    /**
     * Check which components should be ran and run them
     */
    protected function runComponents()
    {
        lgpd()->make(WPML::class);
        lgpd()->make(Router::class);
        lgpd()->make(DataSubjectIdentificator::class);
        lgpd()->make(DataSubjectAdmin::class);
        lgpd()->make(PrivacyToolsPage::class);
        lgpd()->make(PrivacyPolicy::class);        
        lgpd()->make(CookiePopup::class);      
        lgpd()->make(AdvancedIntegration::class);  
        lgpd()->make(PrivacyManager::class);
		lgpd()->make(PrivacySafe::class);
		lgpd()->make( DoNotSell::class );
        lgpd()->make(WordpressComments::class);
        lgpd()->make(WordpressUser::class);
        lgpd()->make(Support::class);

        // Integrations
        lgpd()->make(Themes::class);

        if (defined('WPCF7_VERSION')) {
            lgpd()->make(ContactForm7::class);
        }

        if (defined('FLAMINGO_VERSION')) {
            lgpd()->make(Flamingo::class);
        }

        if ( defined('WC_VERSION') ) {
            lgpd()->make(WooCommerceCcpa::class);
        }
        
        if ( defined('EDD_VERSION') ) {
            lgpd()->make(EddCcpa::class);
        }
        if ( defined('ES_PLUGIN_VERSION') ) {
            lgpd()->make(NewsletterCcpa::class);
        }
    }
}
