<?php

namespace Data443\LGPD;

use Data443\LGPD\Admin\AdminError;
use Data443\LGPD\Admin\AdminNotice;
use Data443\LGPD\Admin\Modal;
use Data443\LGPD\Admin\WordpressAdmin;
use Data443\LGPD\Admin\WordpressAdminPage;
use Data443\LGPD\Components\Consent\ConsentAdmin;
use Data443\LGPD\Installer\Installer;
use Data443\LGPD\Installer\AdminInstallerNotice;
use Data443\LGPD\Admin\AdminPrivacySafe;
/**
 * Register and set up admin components.
 * This class is instantiated at admin_init priority 0
 *
 * Class SetupAdmin
 *
 * @package Data443\LGPD
 */
class SetupAdmin {

	/**
	 * SetupAdmin constructor.
	 */
	public function __construct() {
		$this->registerComponents();
		$this->runComponents();
	}

	/**
	 * Register components in the container
	 */
	protected function registerComponents() {
		lgpd()->singleton( WordpressAdmin::class );
		lgpd()->singleton( WordpressAdminPage::class );
		lgpd()->singleton( Installer::class );

		// Not a singleton.
		lgpd()->alias( AdminNotice::class, 'admin-notice' );
		lgpd()->alias( AdminError::class, 'admin-error' );
		lgpd()->alias( AdminInstallerNotice::class, 'installer-notice' );
		
        lgpd()->alias(AdminPrivacySafe::class, 'privacy-safe');
		lgpd()->alias( Modal::class, 'admin-modal' );
		lgpd()->alias( WordpressAdminPage::class, 'admin-page' );

		lgpd()->bind( ConsentAdmin::class );
	}

	/**
	 * Run components
	 */
	protected function runComponents() {
		lgpd( WordpressAdmin::class );
		lgpd( WordpressAdminPage::class );
		lgpd( Installer::class );
		lgpd( ConsentAdmin::class );
	}
}
